'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function (options) {
  options = options || {};

  var title = options.title;
  var cancelButtonText = options.cancelButtonText;
  var submitButtonText = options.submitButtonText;
  var attributes = options.attributes;
  var attributeNames = _lodash2.default.keys(attributes);

  return _react2.default.createClass({
    displayName: 'Dialog',

    mixins: [_DialogMixin2.default],

    propTypes: {
      model: _react2.default.PropTypes.object.isRequired
    },

    getInitialState: function getInitialState() {
      var that = this;
      var model = this.props.model;

      // Create change callbacks
      this.onChangeCallbacks = _lodash2.default.reduce(attributeNames, function (callbacks, attributeName) {
        callbacks[attributeName] = function (event) {
          var newState = {};
          newState[attributeName] = event.target.value;
          that.setState(newState);
        };
        return callbacks;
      }, {});

      // Create initial state
      return _lodash2.default.reduce(attributeNames, function (initialState, attributeName) {
        initialState[attributeName] = model.data[attributeName];
        return initialState;
      }, {});
    },

    render: function render() {
      var formFields = _lodash2.default.map(attributeNames, function (attributeName) {
        var attribute = attributes[attributeName];
        if (attribute.type === 'string') {
          return _react2.default.createElement(_StringField2.default, {
            key: attributeName,
            attribute: attribute,
            label: attributeName,
            value: this.state[attributeName],
            onChange: this.onChangeCallbacks[attributeName] });
        } else if (attribute.type === 'text') {
          return _react2.default.createElement(_TextField2.default, {
            key: attributeName,
            attribute: attribute,
            label: attributeName,
            value: this.state[attributeName],
            onChange: this.onChangeCallbacks[attributeName] });
        } else if (attribute.type === 'boolean') {
          return _react2.default.createElement(_BooleanField2.default, {
            key: attributeName,
            attribute: attribute,
            label: attributeName,
            value: this.state[attributeName],
            onChange: this.onChangeCallbacks[attributeName] });
        } else if (attribute.type === 'number') {
          return _react2.default.createElement(_NumberField2.default, {
            key: attributeName,
            attribute: attribute,
            label: attributeName,
            value: this.state[attributeName],
            onChange: this.onChangeCallbacks[attributeName] });
        }
      }.bind(this));

      return _react2.default.createElement(
        'div',
        { className: 'modal fade' },
        _react2.default.createElement(
          'div',
          { className: 'modal-dialog' },
          _react2.default.createElement(
            'div',
            { className: 'modal-content' },
            _react2.default.createElement(
              'div',
              { className: 'modal-header' },
              _react2.default.createElement(
                'button',
                { type: 'button', className: 'close', 'data-dismiss': 'modal' },
                _react2.default.createElement(
                  'span',
                  null,
                  '\xD7'
                )
              ),
              _react2.default.createElement(
                'h4',
                { className: 'modal-title' },
                title
              )
            ),
            _react2.default.createElement(
              'div',
              { className: 'modal-body' },
              _react2.default.createElement(
                'form',
                null,
                formFields
              )
            ),
            _react2.default.createElement(
              'div',
              { className: 'modal-footer' },
              _react2.default.createElement(
                'button',
                { type: 'button', className: 'btn btn-default', 'data-dismiss': 'modal' },
                cancelButtonText
              ),
              _react2.default.createElement(
                'button',
                { type: 'button', className: 'btn btn-primary', onClick: this.onSubmit },
                submitButtonText
              )
            )
          )
        )
      );
    }
  });
};

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _DialogMixin = require('../mixins/DialogMixin');

var _DialogMixin2 = _interopRequireDefault(_DialogMixin);

var _StringField = require('../fields/StringField');

var _StringField2 = _interopRequireDefault(_StringField);

var _TextField = require('../fields/TextField');

var _TextField2 = _interopRequireDefault(_TextField);

var _BooleanField = require('../fields/BooleanField');

var _BooleanField2 = _interopRequireDefault(_BooleanField);

var _NumberField = require('../fields/NumberField');

var _NumberField2 = _interopRequireDefault(_NumberField);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

;
module.exports = exports['default'];